#!/usr/bin/env python3.6

import re
import sys
from pathlib import Path

from tabulate import tabulate

LOGDIR = Path('logs')
with open('targets') as f:
    TARGETS = [line.strip() for line in f]


def parse_log(path):
    results = {}
    with path.open() as f:
        for line in f:
            if 'docker build' in line:
                try:
                    results[':'.join(re.search(' -t ([^ ]+) ', line).groups()[0].split(':')[:2])] = False
                except Exception:
                    print(f'fail in {path}: {line} do not contain a valid tag')
            if 'Successfully tagged' in line:
                results[':'.join(line.split()[2].split(':')[:2])] = True
    return results


def show_result(results, target, tag):
    if tag not in results[target]:
        return '  '
    return ' .' if results[target][tag] else ' x'


def get_tags(results):
    # TODO
    return sorted(set(sum((list(results[target].keys()) for target in TARGETS), [])))  # TODO


if __name__ == '__main__':
    results = {}
    table = [[''] + TARGETS]

    for target in TARGETS:
        results[target] = parse_log(LOGDIR / f'build_{target}')

    for tag in get_tags(results):
        table += [[tag] + [show_result(results, target, tag) for target in TARGETS]]

    tablefmt = "simple" if len(sys.argv) < 2 else sys.argv[1]
    print(tabulate(table, tablefmt=tablefmt))
